@@ -65,7 +65,7 @@ r_process_options_default <- function() {
     func = NULL,
     args = list(),
     libpath = .libPaths(),
-    repos = c(getOption("repos"), CRAN = "https://cloud.r-project.org"),
+    repos = default_repos(),
     stdout = "|",
     stderr = "|",
     poll_connection = TRUE,
@@ -75,7 +75,8 @@ r_process_options_default <- function() {
     user_profile = FALSE,
     env = character(),
     supervise = FALSE,
-    load_hook = NULL
+    load_hook = NULL,
+    extra = list()
   )
 }
 
@@ -87,12 +88,13 @@ rcmd_process_options_default <- function() {
     stdout = "|",
     stderr = "|",
     poll_connection = TRUE,
-    repos = c(getOption("repos"), CRAN = "https://cloud.r-project.org"),
+    repos = default_repos(),
     system_profile = FALSE,
     user_profile = FALSE,
     env = rcmd_safe_env(),
     wd = ".",
-    supervise = FALSE
+    supervise = FALSE,
+    extra = list()
   )
 }
 
@@ -104,12 +106,13 @@ rscript_process_options_default <- function() {
     stdout = "|",
     stderr = "|",
     poll_connection = TRUE,
-    repos = c(getOption("repos"), CRAN = "https://cloud.r-project.org"),
+    repos = default_repos(),
     system_profile = FALSE,
     user_profile = FALSE,
     env = rcmd_safe_env(),
     wd = ".",
-    color = FALSE
+    color = FALSE,
+    extra = list()
   )
 }
 
