@@ -68,10 +68,11 @@ rp_init <- function(self, private, super, options) {
 
   with_envvar(
     options$env,
-    super$initialize(options$bin, options$real_cmdargs,
-                     stdout = options$stdout, stderr = options$stderr,
-                     poll_connection = options$poll_connection,
-                     supervise = options$supervise)
+    do.call(super$initialize, c(list(
+      options$bin, options$real_cmdargs, stdout = options$stdout,
+      stderr = options$stderr, poll_connection = options$poll_connection,
+      supervise = options$supervise),
+      options$extra))
   )
 
   invisible(self)
