@@ -178,8 +178,9 @@ rs_init <- function(self, private, super, options, wait, wait_timeout) {
 
   with_envvar(
     options$env,
-    super$initialize(options$bin, options$real_cmdargs, stdin = "|",
-                     stdout = "|", stderr = "|", poll_connection = TRUE)
+    do.call(super$initialize, c(list(options$bin, options$real_cmdargs,
+      stdin = "|", stdout = "|", stderr = "|", poll_connection = TRUE),
+      options$extra))
   )
 
   ## Make child report back when ready
@@ -616,7 +617,7 @@ r_session_options_default <- function() {
     func = NULL,
     args = NULL,
     libpath = .libPaths(),
-    repos = c(getOption("repos"), CRAN = "https://cloud.r-project.org"),
+    repos = default_repos(),
     stdout = NULL,
     stderr = NULL,
     error = getOption("callr.error", "error"),
@@ -625,6 +626,7 @@ r_session_options_default <- function() {
     user_profile = FALSE,
     env = c(TERM = "dumb"),
     supervise = FALSE,
-    load_hook = NULL
+    load_hook = NULL,
+    extra = list()
   )
 }
